@@ -13,14 +13,18 @@ class Validation(ABC):
 		self._dirPath = Path(__file__).resolve().parent
 		self._basePath = self._dirPath.parent.parent.parent
 		self._error = False
+		self._warning = False
 		self._files = dict()
 		self.errors = ''
+		self.warnings = ''
 
 
 	def reset(self, skillPath: Path):
 		self._skillPath = skillPath
 		self._error = False
+		self._warning = False
 		self.errors = ''
+		self.warnings = ''
 
 
 	@property
@@ -28,10 +32,19 @@ class Validation(ABC):
 		return self._error
 
 
+	@property
+	def warning(self) -> bool:
+		return self._warning
+
+
 	def saveIndentedError(self, indent: int, *args):
 		self.errors += ' ' * indent + ' '.join(map(str, args)) + '\n'
 
 
+	def saveIndentedWarning(self, indent: int, *args):
+		self.warnings += ' ' * indent + ' '.join(map(str, args)) + '\n'
+
+
 	@property
 	@abstractmethod
 	def jsonSchema(self) -> dict:
@@ -66,6 +79,13 @@ class Validation(ABC):
 			self.saveIndentedError(0)
 
 
+	def printWarningList(self, warningList: list, indent: int = 0):
+		if warningList:
+			for warning in warningList:
+				self.saveIndentedWarning(indent, '-', warning)
+			self.saveIndentedWarning(0)
+
+
 	def validateJsonSchema(self, file: Path):
 		schema = self.jsonSchema
 		data = self.validateSyntax(file)
